VideoAttribute class

Constructors

VideoAttribute()

Properties

addWaterMark String
getter/setter pair
bitRate String
getter/setter pair
cutByTime String
getter/setter pair
fps String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageType String
getter/setter pair
inputPath String
getter/setter pair
name String
getter/setter pair
outputFilePath String
no setter
outputImagePath String
no setter
outputPath String
getter/setter pair
outputSize String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String
getter/setter pair
videoType String
getter/setter pair
waitTimeOut int
getter/setter pair

Methods

getVideoPreviewImage() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited