VideoOffset class

Constructors

VideoOffset(int dx, int dy)
VideoOffset.bottomLeft()
VideoOffset.bottomRight()
VideoOffset.setWithStringOrder(String dx, String dy)
main_w 视频单帧图像宽度 / Video single frame image width main_h 视频单帧图像高度 / Video single frame image height overlay_w 水印图片的宽度 / The width of the watermark image overlay_h 水印图片的高度 / The height of the watermark image
VideoOffset.topLeft()
VideoOffset.topRight()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited